OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversazione",
    "(Duration %s)" : "(Durata %s)",
    "You attended a call with {user1}" : "Hai partecipato a una chiamata con {user1}",
    "_%n guest_::_%n guests_" : ["%n ospite","%n ospiti","%n ospiti"],
    "You attended a call with {user1} and {user2}" : "Hai partecipato a una chiamata con {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Hai partecipato a una chiamata con {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Hai partecipato a una chiamata con {user1}, {user2}, {user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Hai partecipato a una chiamata con {user1}, {user2}, {user3}, {user4} e {user5}",
    "_%n other_::_%n others_" : ["%n altro","%n altri","%n altri"],
    "{actor} invited you to {call}" : "{actor} ti ha invitato a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Sei stato invitato a una <strong>conversazione</strong> o hai ricevuto una <strong>chiamata</strong>",
    "Other activities" : "Altre attività",
    "Talk" : "Talk",
    "Guest" : "Ospite",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Benvenuti in Nextcloud Talk!\nIn questa conversazione sarai informato sulle nuove funzionalità disponibili in Nextcloud Talk.",
    "## New in Talk %s" : "## Novità in Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge e Safari ora possono essere utilizzati per partecipare a chiamate video e audio",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Le conversazioni uno-a-uno ora sono persistenti e non possono essere più trasformate accidentalmente in conversazioni di gruppo. Inoltre, quando uno dei partecipanti abbandona la conversazione, essa non viene più eliminata automaticamente. Solo se entrambi i partecipanti abbandonano, la conversazione viene eliminata dal server",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Ora puoi informare tutti i partecipanti inserendo \"@all\" nella chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- Con il tasto \"freccia su\" puoi richiamare il tuo ultimo messaggio",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk ora può accettare comandi, invia \"/help\" come un messaggio di chat per vedere se il tuo amministratore li ha configurati",
    "- With projects you can create quick links between conversations, files and other items" : "- Con i progetti puoi creare collegamenti rapidi tra conversazioni, file e altri elementi ",
    "- You can now mention guests in the chat" : "- Ora puoi menzionare gli ospiti nella chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Le conversazioni ora possono avere un ingresso. Questo consente ai moderatori di entrare nella chat e preparare la riunione, mentre gli utenti e gli ospiti devono attendere.",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Ora puoi rispondere direttamente ai messaggi fornendo agli altri utenti altre informazioni sul contesto relativo al tuo messaggio",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- La ricerca di conversazioni e partecipanti ora filtreranno anche le tue conversazioni esistenti, rendendo più semplice trovare conversazioni precedenti",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Ora puoi aggiungere gruppi di utenti personalizzati alle conversazioni quando l'applicazione Cerchie è installata",
    "- Check out the new grid and call view" : "- Controlla la nuova visualizzazione griglia e chiamata",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Ora puoi inviare e trascinare i file direttamente dal tuo dispositivo nella chat",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- I file condivisi ora vengono aperti direttamente dentro la chat con le applicazioni di visualizzazione",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Ora puoi cercare chat e messaggi nella ricerca unificata nella barra in alto",
    "- Spice up your messages with emojis from the emoji picker" : "- Ravviva i tuoi messaggi con le emoji dal selettore di emoji",
    "- You can now change your camera and microphone while being in a call" : "- È ora possibile cambiare la videocamera e il microfono durante una chiamata",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Dai alle tue conversazioni un contesto con una descrizione e pubblicala in modo che gli utenti registrati possano trovarla e unirsi in autonomia",
    "- See a read status and send failed messages again" : "- Visualizza uno stato di lettura e invia nuovamente i messaggi non riusciti ",
    "- Raise your hand in a call with the R key" : "- Alza la mano in una chiamata con il tasto R",
    "- Join the same conversation and call from multiple devices" : "- Partecipa alla stessa conversazione e chiama da più dispositivi",
    "- Send voice messages, share your location or contact details" : "- Invia messaggi vocali, condividi la tua posizione o i dettagli di contatto",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Aggiungi gruppi a una conversazione e i nuovi membri del gruppo verranno automaticamente aggiunti come partecipanti",
    "- A preview of your audio and video is shown before joining a call" : "- Prima di partecipare a una chiamata, viene mostrata un'anteprima dell'audio e del video",
    "- You can now blur your background in the newly designed call view" : "- Ora puoi sfocare lo sfondo nella nuova vista delle chiamate",
    "- Moderators can now assign general and individual permissions to participants" : "- I moderatori ora possono assegnare ai partecipanti autorizzazioni generali e individuali",
    "- You can now react to chat messages" : "- Ora puoi reagire ai messaggi della chat",
    "- In the sidebar you can now find an overview of the latest shared items" : "Nella barra laterale ora puoi trovare una panoramica degli ultimi elementi condivisi",
    "- Configure an expiration time for chat messages" : "- Configura un tempo di scadenza per i messaggi di chat",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Invia messaggi di chat senza notificare i destinatari nel caso in cui non sia urgente",
    "- Chat messages can be translated if a translation provider app is registered" : "- I messaggi di chat possono essere tradotti se è registrata un'applicazione di un fornitore di traduzioni.",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** può ora essere utilizzato nei messaggi di _chat_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhooks sono ora disponibili per implementare bot. Consulta la documentazione per ulteriori informazioni https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Utilizza la conversazione **Nota a me stesso** per prendere appunti e condividere informazioni tra i tuoi dispositivi",
    "Talk updates ✅" : "Aggiornamenti di Talk ✅",
    "Reaction deleted by author" : "Reazione eliminata dall'autore",
    "{actor} created the conversation" : "{actor} ha creato la conversazione",
    "You created the conversation" : "Hai creato la conversazione",
    "System created the conversation" : "Il sistema ha creato la conversazione",
    "An administrator created the conversation" : "Un amministratore ha creato la conversazione",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} ha rinominato la conversazione da \"%1$s\" a \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Hai rinominato la conversazione da \"%1$s\" a \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Un amministratore ha rinominato la conversazione da \"%1$s\" a \"%2$s\"",
    "{actor} set the description" : "{actor} ha impostato la descrizione",
    "You set the description" : "Hai impostato la descrizione",
    "An administrator set the description" : "Un amministratore ha impostato la descrizione",
    "{actor} removed the description" : "{actor} ha rimosso la descrizione",
    "You removed the description" : "Hai rimosso la descrizione",
    "An administrator removed the description" : "Un amministratore ha rimosso la descrizione",
    "You started a call" : "Hai iniziato una chiamata",
    "{actor} started a call" : "{actor} ha iniziato una chiamata",
    "Incoming call" : "Chiamata in arrivo",
    "{actor} joined the call" : "{actor} si è unito alla chiamata",
    "You joined the call" : "Ti sei unito alla chiamata",
    "{actor} left the call" : "{actor} ha abbandonato la chiamata",
    "You left the call" : "Hai abbandonato la chiamata",
    "{actor} unlocked the conversation" : "{actor} ha sbloccato la conversazione",
    "You unlocked the conversation" : "Hai sbloccato la conversazione",
    "An administrator unlocked the conversation" : "Un amministratore ha sbloccato la conversazione",
    "{actor} locked the conversation" : "{actor} ha bloccato la conversazione",
    "You locked the conversation" : "Hai bloccato la conversazione",
    "An administrator locked the conversation" : "Un amministratore ha bloccato la conversazione",
    "{actor} limited the conversation to the current participants" : "{actor} ha ristretto la conversazione ai partecipanti attuali",
    "You limited the conversation to the current participants" : "Hai ristretto la conversazione ai partecipanti attuali",
    "An administrator limited the conversation to the current participants" : "Un amministratore ha ristretto la conversazione ai partecipanti attuali",
    "{actor} opened the conversation to registered users" : "{actor} ha aperto la conversazione agli utenti registrati",
    "You opened the conversation to registered users" : "Hai aperto la conversazione agli utenti registrati",
    "An administrator opened the conversation to registered users" : "Un amministratore ha aperto la conversazione agli utenti registrati",
    "The conversation is now open to everyone" : "La conversazione è ora aperta a chiunque",
    "{actor} opened the conversation to everyone" : "{actor} ha aperto la conversazione a chiunque",
    "You opened the conversation to everyone" : "Hai aperto la conversazione a chiunque",
    "{actor} restricted the conversation to moderators" : "{actor} ha ristretto la conversazione ai moderatori",
    "You restricted the conversation to moderators" : "Hai ristretto la conversazione ai moderatori",
    "{actor} allowed guests" : "{actor} ha permesso gli ospiti",
    "You allowed guests" : "Hai permesso gli ospiti",
    "An administrator allowed guests" : "Un amministratore ha consentito gli ospiti",
    "{actor} disallowed guests" : "{actor} ha vietato gli ospiti",
    "You disallowed guests" : "Hai vietato gli ospiti",
    "An administrator disallowed guests" : "Un amministratore ha vietato gli ospiti",
    "{actor} set a password" : "{actor} ha impostato una password",
    "You set a password" : "Hai impostato una password",
    "An administrator set a password" : "Un amministratore ha impostato una password",
    "{actor} removed the password" : "{actor} ha rimosso la password",
    "You removed the password" : "Hai rimosso la password",
    "An administrator removed the password" : "Un amministratore ha rimosso la password",
    "{actor} added {user}" : "{actor} ha aggiunto {user}",
    "You joined the conversation" : "Ti sei unito alla conversazione",
    "{actor} joined the conversation" : "{actor} si è unito alla conversazione",
    "You added {user}" : "Hai aggiunto {user}",
    "{actor} added you" : "{actor} ti ha aggiunto",
    "An administrator added you" : "Un amministratore ti ha aggiunto",
    "An administrator added {user}" : "Un amministratore ha aggiunto {user}",
    "You left the conversation" : "Hai abbandonato la conversazione",
    "{actor} left the conversation" : "{actor} ha abbandonato la conversazione",
    "{actor} removed {user}" : "{actor} ha rimosso {user}",
    "You removed {user}" : "Hai rimosso {user}",
    "{actor} removed you" : "{actor} ti ha rimosso",
    "An administrator removed you" : "Un amministratore ti ha rimosso",
    "An administrator removed {user}" : "Un amministratore ha rimosso {user}",
    "{actor} invited {federated_user}" : "{actor} ha invitato {federated_user}",
    "You invited {federated_user}" : "Hai invitato {federated_user}",
    "An administrator invited {federated_user}" : "Un amministratore ha invitato {federated_user}",
    "{federated_user} accepted the invitation" : "{l'utente_federato} ha accettato l'invito",
    "{actor} removed {federated_user}" : "{actor} ha rimosso {federated_user}",
    "You removed {federated_user}" : "Hai rimosso {federated_user}",
    "An administrator removed {federated_user}" : "Un amministratore ha rimosso {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} ha rifiutato l'invito",
    "{actor} added group {group}" : "{actor} ha aggiunto il gruppo {group}",
    "You added group {group}" : "Hai aggiunto il gruppo {group}",
    "An administrator added group {group}" : "Un amministratore ha aggiunto il gruppo {group}",
    "{actor} removed group {group}" : "{actor} ha rimosso il gruppo {group}",
    "You removed group {group}" : "Hai rimosso il gruppo {group}",
    "An administrator removed group {group}" : "Un amministratore ha rimosso il gruppo {group}",
    "{actor} added {phone}" : "{actor} ha aggiunto {phone}",
    "You added {phone}" : "Hai aggiunto {phone}",
    "An administrator added {phone}" : "Un amministratore ha aggiunto {phone}",
    "{actor} promoted {user} to moderator" : "{actor} ha promosso {user} a moderatore",
    "You promoted {user} to moderator" : "Hai promosso {user} a moderatore",
    "{actor} promoted you to moderator" : "{actor} ti ha promosso a moderatore",
    "An administrator promoted you to moderator" : "Un amministratore ti ha promosso a moderatore",
    "An administrator promoted {user} to moderator" : "Un amministratore ha promosso {user} a moderatore",
    "{actor} demoted {user} from moderator" : "{actor} ha rimosso {user} da moderatore",
    "You demoted {user} from moderator" : "Hai rimosso {user} da moderatore",
    "{actor} demoted you from moderator" : "{actor} ti ha rimosso da moderatore",
    "An administrator demoted you from moderator" : "Un amministratore ti ha rimosso da moderatore",
    "An administrator demoted {user} from moderator" : "Un amministratore ha rimosso {user} da moderatore",
    "{actor} shared a file which is no longer available" : "{actor} ha condiviso un file che non è più disponibile",
    "You shared a file which is no longer available" : "Hai condiviso un file che non è più disponibile",
    "The shared location is malformed" : "La posizione condivisa è errata",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} ha configurato Matterbridge per sincronizzare questa conversazione con altre chat",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Hai configurato Matterbridge per sincronizzare questa conversazione con altre chat",
    "{actor} updated the Matterbridge configuration" : "{actor} ha aggiornato la configurazione di Matterbridge",
    "You updated the Matterbridge configuration" : "Hai aggiornato la configurazione di Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} ha rimosso la configurazione di Matterbridge",
    "You removed the Matterbridge configuration" : "Hai rimosso la configurazione di Matterbridge",
    "{actor} started Matterbridge" : "{actor} ha avviato Matterbridge",
    "You started Matterbridge" : "Hai avviato Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} ha fermato Matterbridge",
    "You stopped Matterbridge" : "Hai fermato Matterbridge",
    "{actor} deleted a message" : "{actor} ha eliminato un messaggio",
    "You deleted a message" : "Hai eliminato un messaggio",
    "{actor} deleted a reaction" : "{actor} ha eliminato una reazione",
    "You deleted a reaction" : "Hai eliminato una reazione",
    "{actor} cleared the history of the conversation" : "{actor} ha cancellato la cronologia della conversazione",
    "You cleared the history of the conversation" : "Hai cancellato la cronologia della conversazione",
    "Message deleted by author" : "Messaggio eliminato dall'autore",
    "Message deleted by {actor}" : "Messaggio eliminato da {actor}",
    "Message deleted by you" : "Messaggio eliminato da te",
    "Deleted user" : "Utente eliminato",
    "Administration" : "Amministrazione",
    "System" : "Sistema",
    "%s (guest)" : "%s (ospite)",
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} ha terminato la chiamata con %n ospite (Durata {duration})","{actor} ha terminato la chiamata con %n ospiti (Durata {duration})","{actor} ha terminato la chiamata con %n ospiti (Durata {duration})"],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} ha terminato la chiamata con {user1} ospite (Durata {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} ha terminato la chiamata con {user1} e {user2} (Durata {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} ha terminato la chiamata con {user1}, {user2} e {user3} (Durata {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} ha terminato la chiamata con {user1}, {user2}, {user3} e {user4} (Durata {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} ha terminato la chiamata con {user1}, {user2}, {user3}, {user4} e {user5} (Durata {duration})",
    "Talk conversations" : "Conversazioni di Talk",
    "Talk to %s" : "Parla con %s",
    "File is not shared, or shared but not with the user" : "Il file non è condiviso, o condiviso ma non con l'utente",
    "No account available to delete." : "Nessun account disponibile da eliminare.",
    "No image file provided" : "Nessun file immagine fornito",
    "File is too big" : "Il file è troppo grande",
    "Invalid file provided" : "File fornito non valido",
    "Invalid image" : "Immagine non valida ",
    "Unknown filetype" : "Tipo di file sconosciuto ",
    "Talk mentions" : "Menzioni di Talk",
    "Say hi to your friends and colleagues!" : "Saluta i tuoi amici e i tuoi colleghi!",
    "No unread mentions" : "Nessuna menzione non letta",
    "Call in progress" : "Chiamata in corso",
    "You were mentioned" : "Sei stato menzionato",
    "Write to conversation" : "Scrivi nella conversazione",
    "Writes event information into a conversation of your choice" : "Scrive le informazioni di evento in una conversazione di tua scelta",
    "Conversation invitation" : "Inviti di conversazione",
    "Description" : "Descrizione",
    "You can also dial-in via phone with the following details" : "Puoi accedere anche tramite telefono con i seguenti dettagli",
    "Dial-in information" : "Informazioni di accesso",
    "Meeting ID" : "ID riunione",
    "Your PIN" : "Il tuo PIN",
    "Password request: %s" : "Password richiesta: %s",
    "Private conversation" : "Conversazione privata",
    "Deleted user (%s)" : "Utente eliminato (%s)",
    "Dismiss notification" : "Cancella notifica",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "New message" : "Nuovo messaggio",
    "Reminder" : "Promemoria",
    "Notification" : "Notifica",
    "{user} in {call}" : "{user} in {call}",
    "Deleted user in {call}" : "Utente eliminato in {call}",
    "{guest} (guest) in {call}" : "{guest} (guest) in {call}",
    "Guest in {call}" : "Ospite in {call}",
    "{user} sent you a private message" : "{user} ti ha inviato un messaggio privato",
    "{user} sent a message in conversation {call}" : "{user} ha inviato un messaggio nella conversazione {call}",
    "A deleted user sent a message in conversation {call}" : "Un utente eliminato ha inviato un messaggio nella conversazione {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (ospite) ha inviato un messaggio nella conversazione {call}",
    "A guest sent a message in conversation {call}" : "Un ospite ha inviato un messaggio nella conversazione {call}",
    "{user} replied to your private message" : "{user} ha risposto al tuo messaggio privato",
    "{user} replied to your message in conversation {call}" : "{user} ha risposto al tuo messaggio nella conversazione {call}",
    "A deleted user replied to your message in conversation {call}" : "Un utente eliminato ha risposto al tuo messaggio nella conversazione {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (ospite) ha risposto al tuo messaggio nella conversazione {call}",
    "A guest replied to your message in conversation {call}" : "Un ospite ha risposto al tuo messaggio nella conversazione {call}",
    "{user} reacted with {reaction} to your private message" : "{user} ha reagito con {reaction} al tuo messaggio privato",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} ha reagito con {reaction} al tuo messaggio nella conversazione {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Un utente eliminato ha reagito con {reaction} al tuo messaggio nella conversazione {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (guest) ha reagito con {reaction} al tuo messaggio nella conversazione {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Un ospite ha reagito con {reaction} al tuo messaggio nella conversazione {call}",
    "{user} mentioned you in a private conversation" : "{user} ti ha menzionato in una conversazione privata",
    "{user} mentioned you in conversation {call}" : "{user} ti ha menzionato nella conversazione {call}",
    "A deleted user mentioned you in conversation {call}" : "Un utente eliminato ti ha menzionato nella conversazione {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (ospite) ti ha menzionato nella conversazione {call}",
    "A guest mentioned you in conversation {call}" : "Un ospite ti ha menzionato nella conversazione {call}",
    "View chat" : "Visualizza chat",
    "{user} invited you to a group conversation: {call}" : "{user} ti ha invitato a una conversazione di gruppo: {call}",
    "Join call" : "Unisciti alla chiamata",
    "Answer call" : "Rispondi alla chiamata",
    "{user} would like to talk with you" : "{user} vorrebbe parlare con te",
    "Call back" : "Richiama",
    "You missed a call from {user}" : "Hai perso una chiamata da {user}",
    "A group call has started in {call}" : "Una chiamata di gruppo è iniziata in {call}",
    "You missed a group call in {call}" : "Hai perso una chiamata di gruppo in {call}",
    "{email} is requesting the password to access {file}" : "{email} sta richiedendo la password per accedere a {file}",
    "{email} tried to request the password to access {file}" : "{email} ha provato a richiedere la password per accedere a {file}",
    "Someone is requesting the password to access {file}" : "Qualcuno sta richiedendo la password per accedere a {file}",
    "Someone tried to request the password to access {file}" : "Qualcuno ha provato a richiedere la password per accedere a {file}",
    "Open settings" : "Apri impostazioni",
    "The hosted signaling server is now configured and will be used." : "Il server di segnalazione ospitato è ora configurato e sarà utilizzato.",
    "The hosted signaling server was removed and will not be used anymore." : "Il server di segnalazione ospitato è stato rimosso e non sarà più utilizzato.",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "L'account del server di segnalazione ospitato ha modificato lo stato da \"{oldstatus}\" a \"{newstatus}\".",
    "pending" : "in sospeso",
    "error" : "errore",
    "Contact via Talk" : "Contatto tramite Talk",
    "Open Talk" : "Apri Talk",
    "Conversations" : "Conversazioni",
    "{user}" : "{user}",
    "Messages" : "Messaggi",
    "{user} in {conversation}" : "{user} in {conversation}",
    "Messages in other conversations" : "Messaggi in altre conversazioni",
    "Avatar image is not square" : "L'immagine personale non è quadrata",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Richiesta della prova non riuscita perché il server di prova non è raggiungibile. Ritenta più tardi.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Si è verificato un problema con l'autenticazione di questa istanza. Forse non è raggiungibile dall'esterno per verificare l'URL.",
    "Something unexpected happened." : "Si è verificato qualcosa di inatteso.",
    "The URL is invalid." : "L'URL non è valido.",
    "An HTTPS URL is required." : "È richiesto un URL HTTPS.",
    "The email address is invalid." : "L'indirizzo di posta non è valido.",
    "The language is invalid." : "La lingua non è valida.",
    "The country is invalid." : "La nazione non è valida.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Si è verificato un problema con la richiesta della prova. Controlla i registri per ulteriori informazioni.",
    "Too many requests are send from your servers address. Please try again later." : "Troppe richieste inviate dall'indirizzo del tuo server. Riprova più tardi.",
    "There is already a trial registered for this Nextcloud instance." : "Esiste già una versione di prova registrata per questa istanza di Nextcloud.",
    "Something unexpected happened. Please try again later." : "Si è verificato qualcosa di inatteso. Riprova più tardi.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Richiesta della prova non riuscita perché il server di prova si è comportato in modo errato. Ritenta più tardi.",
    "Trial requested but failed to get account information. Please check back later." : "Versione di prova richiesta, ma impossibile ottenere le informazioni sull'account. Controlla più tardi.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Si è verificato un problema con l'autenticazione di questa richiesta. Forse non è raggiungibile dall'esterno per verificare l'URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Impossibile recuperare le informazioni sull'account perché il server di prova si è comportato in modo errato. Controlla più tardi.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Si è verificato un problema con il recupero delle informazioni sull'account. Controlla i registri per ulteriori informazioni.",
    "There is no such account registered." : "Non c'è nessun account di questo tipo registrato.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Impossibile recuperare le informazioni sull'account perché il server di prova non è raggiungibile. Controlla più tardi.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Eliminazione dell'account del server di segnalazione ospitato non riuscita. Controlla più tardi.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Impossibile eliminare l'account perché il server di prova si è comportato in modo errato. Controlla più tardi.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Si è verificato un problema con l'eliminazione dell'account. Controlla i registri per ulteriori informazioni.",
    "Too many requests are sent from your servers address. Please try again later." : "Troppe richieste inviate dall'indirizzo del tuo server. Riprova più tardi.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Impossibile eliminare l'account perché il server di prova non è raggiungibile. Controlla più tardi.",
    "Note to self" : "Nota a me stesso",
    "A place for your private notes, thoughts and ideas" : "Un posto per i tuoi appunti, pensieri e idee privati",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirati Arabi Uniti",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua e Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antartide",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americane",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Isole Åland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia ed Erzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgio",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthelemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bolivia, Plurinational State of" : "Bolivia, Stato Plurinazionale di",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius e Saba",
    "Brazil" : "Brasile",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Isola Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorussia",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Isole Cocos (Keeling)",
    "Congo, the Democratic Republic of the" : "Congo, Repubblica Democratica del",
    "Central African Republic" : "Repubblica Centrafricana",
    "Congo" : "Congo",
    "Switzerland" : "Svizzera",
    "Côte d'Ivoire" : "Costa d'Avorio",
    "Cook Islands" : "Isole di Cook",
    "Chile" : "Cile",
    "Cameroon" : "Camerun",
    "China" : "Cina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Capo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Isola di Natale",
    "Cyprus" : "Cipro",
    "Czechia" : "Cechia",
    "Germany" : "Germania",
    "Djibouti" : "Gibuti",
    "Denmark" : "Danimarca",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Repubblica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egitto",
    "Western Sahara" : "Sahara occidentale",
    "Eritrea" : "Eritrea",
    "Spain" : "Spagna",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Figi",
    "Falkland Islands (Malvinas)" : "Isole Falkland (Malvinas)",
    "Micronesia, Federated States of" : "Micronesia, Stati Federati di",
    "Faroe Islands" : "Isole Faroe",
    "France" : "Francia",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Regno Unito di Gran Bretagna e Irlanda del Nord",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana Francese",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibilterra",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupa",
    "Equatorial Guinea" : "Guinea Equatoriale",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Georgia del Sud e Isole Sandwich Australi",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Isole Heard e McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croazia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungheria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israele",
    "Isle of Man" : "Isola di Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territorio Britannico dell'Oceano Indiani",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Iran, Repubblica Islamica dell'",
    "Iceland" : "Islanda",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Giamaica",
    "Jordan" : "Giordania",
    "Japan" : "Giappone",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirghizistan",
    "Cambodia" : "Cambogia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comore",
    "Saint Kitts and Nevis" : "Saint Kitts e Nevis",
    "Korea, Democratic People's Republic of" : "Corea, Repubblica Democratica Popolare di",
    "Korea, Republic of" : "Corea, Repubblica di",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Isole Cayman",
    "Kazakhstan" : "Kazakistan",
    "Lao People's Democratic Republic" : "Repubblica Democratica Popolare del Laos",
    "Lebanon" : "Libano",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Lussemburgo",
    "Latvia" : "Lettonia",
    "Libya" : "Libia",
    "Morocco" : "Marocco",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldavia, Repubblica di",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (parte francese)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Isole Marshall",
    "North Macedonia" : "Macedonia del Nord",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Isole Marianne settentrionali",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldive",
    "Malawi" : "Malawi",
    "Mexico" : "Messico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambico",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nuova Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Isola Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Paesi Bassi",
    "Norway" : "Norvegia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nuova Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Perù",
    "French Polynesia" : "Polinesia Francese",
    "Papua New Guinea" : "Papua Nuova Guinea",
    "Philippines" : "Filippine",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "Saint Pierre e Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Porto Rico",
    "Palestine, State of" : "Palestina, Stato di",
    "Portugal" : "Portogallo",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Federazione Russa",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Isole Salomone",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Svezia",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sant'Elena, Ascensione e Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard e Jan Mayen",
    "Slovakia" : "Slovacchia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan del Sud",
    "Sao Tome and Principe" : "Sao Tome e Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (parte olandese)",
    "Syrian Arab Republic" : "Repubblica Araba Siriana",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Isole Turks e Caicos",
    "Chad" : "Ciad",
    "French Southern Territories" : "Terre Australi Francesi",
    "Togo" : "Togo",
    "Thailand" : "Thailandia",
    "Tajikistan" : "Tagikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Est",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Turchia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan, provincia della Cina",
    "Tanzania, United Republic of" : "Tanzania, Repubblica Unita di",
    "Ukraine" : "Ucraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Isole minori esterne degli Stati Uniti d'America",
    "United States of America" : "Stati Uniti d'America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Città del Vaticano",
    "Saint Vincent and the Grenadines" : "Saint Vincent e Grenadine",
    "Venezuela, Bolivarian Republic of" : "Venezuela, Repubblica Bolivariana di",
    "Virgin Islands, British" : "Isole Vergini, Britanniche",
    "Virgin Islands, U.S." : "Isole Vergini, U.S.A.",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sudafrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Federazione",
    "High-performance backend" : "Motore ad alte prestazioni",
    "Error: Cannot connect to server" : "Errore: impossibile connettersi al server",
    "Error: Server did not respond with proper JSON" : "Errore: il server non ha risposto con il JSON corretto",
    "Could not get version" : "Impossibile ottenere la versione",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Errore: versione in esecuzione: {version}; Il server deve essere aggiornato per essere compatibile con questa versione di Talk",
    "Error: Server responded with: {error}" : "Errore: il server ha risposto con: {error}",
    "Error: Unknown error occurred" : "Errore: si è verificato un errore sconosciuto",
    "SIP configuration" : "Configurazione SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non valida, il formato della data deve essere AAAA-MM-GG",
    "Conversation not found" : "Conversazione non trovata",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, video e audio conferenze utilizzando WebRTC",
    "Leave call" : "Lascia la chiamata",
    "Navigating away from the page will leave the call in {conversation}" : "L'abbandono della pagina causerà l'uscita dalla chiamata in {conversation}",
    "Stay in call" : "Rimani in conversazione",
    "Discuss this file" : "Discuti questo file",
    "Share this file with others to discuss it" : "Condividi questo file con altri per discuterne",
    "Share this file" : "Condividi questo file",
    "Join conversation" : "Unisciti alla conversazione",
    "Request password" : "Richiedi password",
    "Error requesting the password." : "Errore durante la richiesta della password",
    "This conversation has ended" : "Questa conversazione è terminata",
    "Close Talk sidebar" : "Chiudi la barra laterale di Talk",
    "Open Talk sidebar" : "Aprire la barra laterale di Talk",
    "Everyone" : "Tutti",
    "Users and moderators" : "Utenti e moderatori",
    "Moderators only" : "Solo i moderatori",
    "Save changes" : "Salva le modifiche",
    "Saving …" : "Salvataggio in corso...",
    "Saved!" : "Salvato!",
    "Limit to groups" : "Limita a gruppi",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Quando almeno un gruppo è selezionato, solo le persone dei gruppi elencati possono prendere parte alla conversazione.",
    "Guests can still join public conversations." : "Gli ospiti possono unirsi a conversazioni pubbliche.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Gli utenti che non possono più usare Talk verranno comunque elencati tra i partecipanti nelle loro conversazioni precedenti e verranno anche mantenuti i loro messaggi.",
    "Limit using Talk" : "Limita l'utilizzo di Talk",
    "Limit creating a public and group conversation" : "Limita alla creazione di una conversazione pubblica e di gruppo",
    "Limit creating conversations" : "Limita la creazione di conversazioni",
    "Limit starting a call" : "Limita l'inizio di una chiamata",
    "Limit starting calls" : "Limita l'inizio della chiamate",
    "When a call has started, everyone with access to the conversation can join the call." : "Quando una chiamata è iniziata, chiunque abbia accesso alla conversazione può unirsi alla chiamata.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "I seguenti bot sono installati su questo server. Nella documentazione puoi trovare i dettagli su come {linkstart1}creare il tuo bot{linkend} o una {linkstart2}lista di bot{linkend} da abilitare sul tuo server.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Nessun bot è installato su questo server. Nella documentazione puoi trovare i dettagli su come {linkstart1}creare il tuo bot{linkend} o una {linkstart2}lista di bot{linkend} da abilitare sul tuo server.",
    "Enabled" : "Abilitata",
    "Disabled" : "Disattivato",
    "Bots settings" : "Impostazioni dei bot",
    "State" : "Stato",
    "Name" : "Nome",
    "Find more bots" : "Trova altri bot",
    "Beta" : "Beta",
    "Enable Federation in Talk app" : "Abilita la federazione nell'applicazione Talk",
    "Permissions" : "Permessi",
    "All messages" : "Tutti i messaggi",
    "@-mentions only" : "solo @-menzioni",
    "Off" : "Spento",
    "General settings" : "Impostazioni generali",
    "Default notification settings" : "Impostazioni di notifica predefinite",
    "Default group notification" : "Notifica di gruppo predefinita",
    "Default group notification for new groups" : "Notifica di gruppo predefinita per i nuovi gruppi",
    "Integration into other apps" : "Integrazione in altre applicazioni",
    "Allow conversations on files" : "Consenti conversazioni su file",
    "Allow conversations on public shares for files" : "Consenti conversazioni su condivisioni pubbliche per i file",
    "Enable encryption" : "Abilita cifratura",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Facendo clic sul pulsante sopra le informazioni nel modulo sono inviate ai server di Struktur AG. Ulteriori informazioni sono disponibili su {linkstart}spreed.eu{linkend}.",
    "Pending" : "In corso",
    "Error" : "Errore",
    "Blocked" : "Bloccati",
    "Active" : "Attivo",
    "Expired" : "Scaduto",
    "The trial could not be requested. Please try again later." : "La prova non può essere richiesta. Riprova più tardi.",
    "The account could not be deleted. Please try again later." : "Non è stato possibile eliminare l'account. Riprova più tardi.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Il nostro partner Struktur AG fornisce un servizio in cui è possibile richiedere un server di segnalazione ospitato. Per questo è sufficiente compilare il modulo sottostante e Nextcloud lo richiederà. Una volta impostato il server, le credenziali saranno riempite automaticamente. Ciò sovrascriverà le impostazioni esistenti del server di segnalazione.",
    "URL of this Nextcloud instance" : "URL di questa istanza Nextcloud",
    "Full name of the user requesting the trial" : "Nome completo dell'utente che richiede la prova",
    "Email of the user" : "Indirizzo di posta dell'utente",
    "Language" : "Lingua",
    "Country" : "Nazione",
    "Request signaling server trial" : "Richiesta della prova del server di segnalazione",
    "You can see the current status of your hosted signaling server in the following table." : "Puoi visualizzare lo stato attuale del server di segnalazione ospitato nella seguente tabella.",
    "Status" : "Stato",
    "Created at" : "Creato il",
    "Expires at" : "Scade il",
    "Limits" : "Limiti",
    "Delete the signaling server account" : "Elimina l'account del server di segnalazione",
    "_%n user_::_%n users_" : ["%n utente","%n utenti","%n utenti"],
    "Installed version: {version}" : "Versione installata: {version}",
    "Matterbridge binary was not found or couldn't be executed." : "Il binario di Matterbridge non è stato trovato o non può essere eseguito.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Puoi impostare il percorso del binario di Matterbridge anche manualmente tramite la configurazione. Controlla la {linkstart}documentazione di integrazione di Matterbridge{linkend} per ulteriori informazioni.",
    "Downloading …" : "Scaricamento…",
    "Install Talk Matterbridge" : "Installa Talk Matterbridge",
    "Failed to execute Matterbridge binary." : "Esecuzione del binario di Matterbridge non riuscita.",
    "Matterbridge integration" : "Integrazione con Matterbridge",
    "Enable Matterbridge integration" : "Attiva l'integrazione con Matterbridge",
    "Status: Checking connection" : "Stato: controllo della connessione",
    "OK: Running version: {version}" : "OK: versione in esecuzione: {version}",
    "Validate SSL certificate" : "Convalida certificato SSL",
    "Delete this server" : "Elimina questo server",
    "Test this server" : "Prova questo server",
    "The consent to be recorded will be required for each participant before joining every call." : "Il consenso per la registrazione sarà richiesto ad ogni partecipante prima di accedere a ciascuna chiamata.",
    "Shared secret" : "Segreto condiviso",
    "Recording consent" : "Permesso di registrazione",
    "Restrict SIP configuration" : "Limita configurazione SIP",
    "Enable SIP configuration" : "Abilita configurazione SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Solo gli utenti dei seguenti gruppi possono abilitare SIP nelle conversazioni che moderano",
    "Phone number (Country)" : "Numero di telefono (Nazione)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Queste informazioni sono inviate tramite email di invito e visualizzate nella barra laterale a tutti i partecipanti.",
    "High-performance backend URL" : "URL del motore ad alte prestazioni",
    "STUN server URL" : "URL server STUN",
    "STUN servers" : "Server STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un server STUN è utilizzato per determinare l'indirizzo IP pubblico dei partecipanti dietro a un router.",
    "{schema} scheme must be used with a domain" : "Lo schema {schema} deve essere utilizzata con un dominio",
    "{option1} and {option2}" : "{option1} e {option2}",
    "{option} only" : "solo {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: Candidati ICE validi restituiti dal server TURN",
    "Error: No working ICE candidates returned by the TURN server" : "OK: Candidati ICE non funzionanti restituiti dal server TURN",
    "Testing whether the TURN server returns ICE candidates" : "Verifica se il server TURN restituisce candidati",
    "TURN server schemes" : "Schemi del server TURN",
    "TURN server URL" : "URL server TURN",
    "TURN server secret" : "Segreto del server TURN",
    "TURN server protocols" : "Protocolli server TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Un server TURN viene utilizzato per inoltrare il traffico dai partecipanti dietro un firewall. Se i singoli partecipanti non possono connettersi ad altri, è molto probabile che sia richiesto un server TURN. Vedi {linkstart}questa documentazione{linkend} per le istruzioni di configurazione.",
    "TURN servers" : "Server TURN",
    "Failed" : "Non riuscito",
    "OK" : "OK",
    "Checking …" : "Controllo in corso…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Fallito: WebAssembly è disabilitato o non è supportato in questo browser. Abilita WebAssembly o utilizza un browser con supporto per eseguire il controllo.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Fallito: i file \".wasm\" e \".tflite\" non sono stati restituiti correttamente dal server Web. Si prega di controllare la sezione \"Requisiti di sistema\" nella documentazione di Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: i file \".wasm\" e \".tflite\" sono stati correttamente restituiti dal server web.",
    "Web server setup checks" : "Verifiche della configurazione del server Web",
    "Federated user" : "Utente federato",
    "Confirm" : "Conferma",
    "Reset" : "Ripristina",
    "Back" : "Indietro",
    "Cancel" : "Annulla",
    "Add participant \"{user}\"" : "Aggiungi il partecipante \"{user}\"",
    "Now" : "Ora",
    "Loading …" : "Caricamento…",
    "From" : "Da",
    "To" : "A",
    "Calendar" : "Calendario",
    "Attendees" : "Partecipanti",
    "Save" : "Salva",
    "Search participants" : "Cerca partecipanti",
    "No results" : "Nessun risultato",
    "Done" : "Completato",
    "Raise hand" : "Alza la mano",
    "Raise hand (R)" : "Alza la mano (R)",
    "Lower hand" : "Abbassa la mano",
    "Lower hand (R)" : "Abbassa la mano (R)",
    "Exit full screen (F)" : "Esci dalla modalità a schermo intero (F)",
    "Full screen (F)" : "Schermo intero (F)",
    "Speaker view" : "Visualizzazione oratore",
    "Grid view" : "Vista Griglia",
    "You need to close a dialog to toggle full screen" : "È necessario chiudere una finestra per passare alla modalità a schermo intero",
    "This conversation is read-only" : "Questa conversazione è in sola lettura",
    "{nickName} raised their hand." : "{nickName} ha alzato la mano.",
    "A participant raised their hand." : "Un partecipante ha alzato la mano.",
    "Collapse stripe" : "Contrai striscia",
    "Expand stripe" : "Espandi striscia",
    "Previous page of videos" : "Pagina di video precedente",
    "Next page of videos" : "Pagina di video successiva",
    "Connecting …" : "Connessione in corso…",
    "Waiting for others to join the call …" : "In attesa che altri si uniscano alla chiamata...",
    "You can invite others in the participant tab of the sidebar" : "Puoi invitare altri nella scheda dei partecipanti della barra laterale",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Puoi invitare altri nella scheda dei partecipanti della barra laterale o condividere questo collegamento per invitarli!",
    "Share this link to invite others!" : "Condividi questo collegamento per invitare altri!",
    "Copy link" : "Copia collegamento",
    "You are not allowed to enable audio" : "Non sei autorizzato ad abilitare l'audio",
    "Mute audio" : "Silenzia audio",
    "Mute audio (M)" : "Silenzia audio (M)",
    "Unmute audio" : "Rimuovi silenzio audio",
    "Unmute audio (M)" : "Rimuovi silenzio audio (M)",
    "None" : "Nessuno",
    "Access to camera was denied" : "L'accesso alla fotocamera è stato negato",
    "Error while accessing camera: It is likely in use by another program" : "Errore durante l'accesso alla fotocamera: È probabile che sia utilizzata da un altro programma",
    "Error while accessing camera" : "Errore durante l'accesso alla fotocamera",
    "You have been muted by a moderator" : "Sei stato silenziato da un moderatore",
    "You are not allowed to enable video" : "Non sei autorizzato ad abilitare il video",
    "Disable video" : "Disabilita video",
    "Disable video (V)" : "Disabilita video (V)",
    "Enable video" : "Abilita video",
    "Enable video (V)" : "Abilita video (V)",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Abilita video (V) - La tua connessione sarà interrotta brevemente quando abiliti il video per la prima volta",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Abilita video. La tua connessione sarà interrotta brevemente quando abiliti il video per la prima volta",
    "You" : "Tu",
    "Mute" : "Silenzia",
    "Show screen" : "Mostra schermo",
    "Stop following" : "Smetti di seguire",
    "Connection could not be established …" : "Impossibile stabilire la connessione...",
    "Connection was lost and could not be re-established …" : "La connessione è stata persa e non è stato possibile ristabilirla...",
    "Connection could not be established. Trying again …" : "Impossibile stabilire la connessione. Riprova...",
    "Connection lost. Trying to reconnect …" : "Connessione persa. Tentativo di riconnessione...",
    "Connection problems …" : "Problemi di connessione...",
    "Collapse" : "Contrai",
    "Expand" : "Espandi",
    "You need to be logged in to upload files" : "Devi aver eseguito l'accesso per caricare file",
    "Drop your files to upload" : "Rilascia i tuoi file per caricarli",
    "Conversation messages" : "Messaggi della conversazione",
    "Scroll to bottom" : "Scorri in fondo",
    "Post message" : "Pubblica messaggio",
    "Favorite" : "Preferito",
    "Date:" : "Data:",
    "Note:" : "Nota:",
    "Hide details" : "Nascondi dettagli",
    "Show details" : "Mostra dettagli",
    "Error while updating conversation description" : "Errore durante l'aggiornamento della descrizione della conversazione",
    "Edit conversation description" : "Modifica la descrizione della conversazione",
    "Enter a description for this conversation" : "Inserisci una descrizione per questa conversazione",
    "Picture" : "Immagine",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "I seguenti bot possono essere abilitati in questa conversazione. Contatta il tuo amministratore per installare altri bot su questo server.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Nessun bot è installato su questo server. Contatta il tuo amministratore per installare bot su questo server.",
    "Disable" : "Disabilita",
    "Enable" : "Abilita",
    "Choose" : "Scegli",
    "The file must be a PNG or JPG" : "Il file deve essere una PNG o JPG",
    "Default permissions modified for {conversationName}" : "Permessi predefiniti modificati per {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Impossibile modificare i permessi predefiniti per {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Modifica i permessi predefiniti per i partecipanti di questa conversazione. Queste impostazioni non hanno effetto sui moderatori.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Ogni volta che i permessi vengono modificati in questa sezione i permessi impostati precedentemente a singoli partecipanti vanno perduti.",
    "All permissions" : "Tutti permessi",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "I partecipanti hanno le autorizzazioni per avviare una chiamata, partecipare a una chiamata, abilitare audio e video e condividere lo schermo.",
    "Restricted" : "Limitato",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "I partecipanti possono partecipare alle chiamate, ma non possono abilitare né audio né video né condividere lo schermo finché un moderatore non concede loro manualmente i permessi.",
    "Advanced permissions" : "Permessi avanzati",
    "Edit permissions" : "Modifica permessi",
    "Meeting" : "Riunione",
    "Conversation settings" : "Impostazioni conversazione",
    "Basic Info" : "Informazioni di base",
    "Personal" : "Personale",
    "Moderation" : "Moderazione",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bot",
    "Danger zone" : "Zona pericolosa",
    "Do you really want to delete \"{displayName}\"?" : "Vuoi davvero eliminare \"{displayName}\"?",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Vuoi davvero eliminare tutti i messaggi in \"{displayName}\"?",
    "Error while deleting conversation" : "Errore durante l'eliminazione della conversazione",
    "Error while clearing chat history" : "Errore durante la cancellazione della cronologia chat",
    "Be careful, these actions cannot be undone." : "Fai attenzione, queste azioni non possono essere annullate.",
    "Leave conversation" : "Lascia la conversazione",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Una volta terminata una conversazione, per rientrare in una conversazione chiusa, è necessario un invito. È possibile riprendere una conversazione aperta in qualsiasi momento.",
    "No" : "No",
    "Yes" : "Sì",
    "Delete conversation" : "Elimina conversazione",
    "Permanently delete this conversation." : "Elimina definitivamente questa conversazione.",
    "Delete chat messages" : "Elimina i messaggi di chat",
    "Permanently delete all the messages in this conversation." : "Elimina definitivamente tutti i messaggi di questa conversazione.",
    "Delete all chat messages" : "Elimina tutti i messaggi di chat",
    "Message expiration" : "Imposta la scadenza dei messaggi",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "I messaggi di chat possono scadere dopo un certo periodo di tempo. Nota: I file condivisi in chat non saranno eliminati per il proprietario, ma non saranno più condivisi nella conversazione.",
    "Guest access" : "Accesso ospiti",
    "Allow guests to join this conversation via link" : "Permetti agli ospiti di unirsi alla conversazione via link",
    "Password protection" : "Protezione con password",
    "Set a password" : "Imposta una password",
    "Save password" : "Salva la password",
    "Resend invitations" : "Nuovo invio degli inviti",
    "This conversation is limited to the current participants" : "Questa conversazione è limitata ai partecipanti attuali",
    "Error occurred when opening or limiting the conversation" : "Si è verificato un errore durante l'apertura o la limitazione della conversazione",
    "Open conversation to registered users, showing it in search results" : " Permetti l’accesso alla conversazione agli utenti registrati, mostrandoli tra i risultati di ricerca",
    "Start time has been updated" : "L'orario di inizio è stato aggiornato",
    "Error occurred while updating start time" : "Si è verificato un errore durante l'aggiornamento dell'orario di inizio",
    "Enable lobby, restricting the conversation to moderators" : "Abilita la lobby, limitando la conversazione ai moderatori",
    "Meeting start time" : "Orario di inizio della riunione",
    "Start time (optional)" : "Ora iniziale (facoltativa)",
    "Error occurred when locking the conversation" : "Si è verificato un errore durante il blocco della conversazione",
    "Error occurred when unlocking the conversation" : "Si è verificato un errore durante lo sblocco della conversazione",
    "Lock conversation" : "Blocca conversazione",
    "This will also terminate the ongoing call." : "Ciò terminerà la chiamata in corso.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Blocca la conversazione per evitare che qualcuno pubblichi messaggi o inizi una call.",
    "Edit" : "Modifica",
    "More information" : "Altre informazioni",
    "Delete" : "Elimina",
    "Add new bridged channel to current conversation" : "Abilita nuovo canale collegato alla conversazione attuale",
    "unknown state" : "stato sconosciuto",
    "running" : "in esecuzione",
    "not running, check Matterbridge log" : "non in esecuzione, controlla il log di Matterbridge",
    "not running" : "non in esecuzione",
    "Bridge saved" : "Collegamento salvato",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Puoi collegare canali da vari sistemi di messaggistica istantanea con Matterbridge.",
    "More info on Matterbridge" : "Ulteriori informazioni su Matterbridge",
    "Enable bridge" : "Abilita collegamento",
    "Show Matterbridge log" : "Mostra il log di Matterbridge",
    "Log content" : "Contenuto dei log",
    "Notifications" : "Notifiche",
    "Notify about calls in this conversation" : "Notifica delle chiamate in questa conversazione",
    "Important conversation" : "Conversazione importante",
    "Recording consent is required for all calls" : "Il permesso di registrazione è richiesto per tutte le call",
    "SIP dial-in is now enabled" : "L'accesso SIP è ora abilitato",
    "SIP dial-in is now disabled" : "L'accesso SIP è ora disabilitato",
    "Error occurred when enabling SIP dial-in" : "Si è verificato un errore durante l'abilitazione dell'accesso SIP",
    "Error occurred when disabling SIP dial-in" : "Si è verificato un errore durante la disabilitazione dell'accesso SIP",
    "Join" : "Partecipa",
    "Error while creating the conversation" : "Errore durante la creazione della conversazione",
    "Create a new conversation" : "Crea una nuova conversazione",
    "Unread mentions" : "Menzioni non lette",
    "Create conversation" : "Crea conversazione",
    "Enter your name" : "Digita il tuo nome",
    "Log in" : "Login",
    "Browse" : "Sfoglia",
    "Mark as read" : "Marca come letto",
    "Mark as unread" : "Marca come non letto",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add to favorites" : "Aggiungi ai preferiti",
    "You need to promote a new moderator before you can leave the conversation." : "Devi promuovere un nuovo moderatore prima di poter abbandonare la conversazione. ",
    "Conversation actions" : "Azioni delle conversazioni",
    "Unread" : "Da leggere",
    "No matches found" : "Nessuna corrispondenza trovata",
    "No conversations found" : "Nessuna conversazione trovata",
    "An error occurred while performing the search" : "Si è verificato un errore durante l'esecuzione della ricerca",
    "Conversation list" : "Elenco delle conversazioni",
    "Unread messages" : "Messaggi non letti",
    "Clear filter" : "Pulisci il filtro",
    "Talk settings" : "Impostazioni di Talk",
    "Users" : "Utenti",
    "Groups" : "Gruppi",
    "Open conversations" : "Apri conversazioni",
    "No search results" : "Nessun risultato di ricerca",
    "Users and groups" : "Utenti e gruppi",
    "Other sources" : "Altre fonti",
    "The meeting will start soon" : "La riunione inizierà presto",
    "This meeting is scheduled for {startTime}" : "Questa riunione è programmata per {startTime}",
    "You are currently waiting in the lobby" : "Stai attualmente aspettando nell'ingresso",
    "Select microphone" : "Seleziona microfono",
    "No microphone available" : "Nessun microfono disponibile",
    "Select camera" : "Seleziona fotocamera",
    "No camera available" : "Nessuna fotocamera disponibile",
    "Select a device" : "Seleziona un dispositivo",
    "Test" : "Prova",
    "Devices" : "Dispositivi",
    "No audio" : "Nessun audio",
    "No camera" : "Nessuna fotocamera",
    "Calls are not supported in your browser" : "Le chiamate non sono supportate dal tuo browser",
    "Access to microphone is only possible with HTTPS" : "L'accesso a microfono è possibile solo con HTTPS",
    "Access to microphone was denied" : "L'accesso al microfono è stato negato",
    "Error while accessing microphone" : "Errore durante l'accesso al microfono",
    "Access to camera is only possible with HTTPS" : "L'accesso alla fotocamera è possibile solo con HTTPS",
    "Select a file" : "Seleziona un file",
    "Invalid path selected" : "Percorso selezionato non valido",
    "Blur" : "Sfocatura",
    "Upload" : "Carica",
    "Files" : "File",
    "Message read by everyone who shares their reading status" : "Messaggio letto da tutti coloro che condividono il proprio stato di lettura",
    "Message sent" : "Messaggio inviato",
    "Deleting message" : "Eliminazione del messaggio",
    "Message deleted successfully" : "Messaggio eliminato correttamente",
    "Message could not be deleted because it is too old" : "Impossibile eliminare il messaggio perché è troppo datato",
    "Only normal chat messages can be deleted" : "È possibile eliminare solo i normali messaggi di chat",
    "An error occurred while deleting the message" : "Si è verificato un errore durante l'eliminazione del messaggio",
    "Later today – {timeLocale}" : "Oggi – {timeLocale}",
    "Set reminder for later today" : "Imposta promemoria per più tardi oggi",
    "Tomorrow – {timeLocale}" : "Domani – {timeLocale}",
    "Set reminder for tomorrow" : "Imposta promemoria per domani",
    "This weekend – {timeLocale}" : "Questo fine settimana – {timeLocale}",
    "Set reminder for this weekend" : "Imposta promemoria per questo fine settimana",
    "Next week – {timeLocale}" : "Prossima settimana – {timeLocale}",
    "Set reminder for next week" : "Imposta promemoria per la prossima settimana",
    "Message forwarded to \"Note to self\"" : "Messaggio inoltrato a \"Nota a me stesso\"",
    "Error while forwarding message to \"Note to self\"" : "Errore durante l'inoltro del messaggio a \"Nota a me stesso\"",
    "Reply" : "Rispondi",
    "Set reminder" : "Imposta promemoria",
    "Reply privately" : "Rispondi privatamente",
    "Edit message" : "Modifica messaggio",
    "Copy message link" : "Copia collegamento del messaggio",
    "Go to file" : "Vai al file",
    "Forward message" : "Messaggio inoltrato",
    "Translate" : "Traduci",
    "Set custom reminder" : "Imposta promemoria personalizzato",
    "Choose a conversation to forward the selected message." : "Seleziona una conversazione per inoltrare il messaggio selezionato.",
    "Error while forwarding message" : "Errore durante l'inoltro del messaggio",
    "The message has been forwarded to {selectedConversationName}" : "Il messaggio è stato inoltrato a {selectedConversationName}",
    "Dismiss" : "Annulla",
    "Go to conversation" : "Vai alla conversazione",
    "Translate from" : "Traduci da",
    "Translate to" : "Traduci in",
    "Your browser does not support playing audio files" : "Il tuo browser non supporta la riproduzione di file audio",
    "Contact" : "Contatto",
    "{stack} in {board}" : "{stack} in {board}",
    "Deck Card" : "Scheda di Deck",
    "Remove {fileName}" : "Rimuovi {fileName}",
    "Open this location in OpenStreetMap" : "Apri questa posizione in OpenStreetMap",
    "Sending message" : "Invio del messaggio",
    "Failed to send the message. Click to try again" : "Invio del messaggio non riuscito. Fare clic per riprovare",
    "Not enough free space to upload file" : "Spazio libero insufficiente per caricare il file",
    "You are not allowed to share files" : "Non ti è consentito condividere file",
    "You cannot send messages to this conversation at the moment" : "Non puoi inviare messaggi in questa conversazione al momento",
    "Copy code block" : "Copia blocco di codice",
    "Poll" : "Sondaggio",
    "Today" : "Oggi",
    "Yesterday" : "Ieri",
    "_%n day ago_::_%n days ago_" : ["%d giorno fa","%n giorni fa","%n giorni fa"],
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "No messages" : "Nessun messaggio",
    "Create a new group conversation" : "Crea una nuova conversazione di gruppo",
    "Add participants" : "Aggiungi partecipanti",
    "Allow guests to join via link" : "Consenti agli ospiti di partecipare tramite collegamento",
    "Enter password" : "Digita la password",
    "This conversation has been locked" : "Questa conversazione è stata bloccata",
    "No permission to post messages in this conversation" : "Nessun permesso per pubblicare messaggi in questa conversazione",
    "Joining conversation …" : "Partecipazione alla conversazione...",
    "Send message" : "Invia messaggio",
    "File to share" : "File da condividere",
    "Add emoji" : "Aggiungi emoji",
    "Share from Files" : "Condividi da File",
    "Share files to the conversation" : "Condividi file nella conversazione",
    "Upload from device" : "Carica dal dispositivo",
    "Create new poll" : "Crea nuovo sondaggio",
    "Smart picker" : "Selettore intelligente",
    "Record voice message" : "Registra messaggio vocale",
    "End recording and send" : "Termina la registrazione e invia",
    "Dismiss recording" : "Annulla la registrazione",
    "Access to the microphone was denied" : "L'accesso al microfono è stato negato",
    "Microphone either not available or disabled in settings" : "Microfono non disponibile o disabilitato nelle impostazioni",
    "Error while recording audio" : "Errore durante la registrazione dell'audio",
    "Talk recording from {time} ({conversation})" : "Registrazione della conversazione da {time} ({conversation})",
    "New file" : "Nuovo file",
    "Blank" : "Vuoto",
    "Add more files" : "Aggiungi altri file",
    "Send" : "Invia",
    "In this conversation <strong>{user}</strong> can:" : "In questa conversazione <strong>{utente}</strong> può:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Modifica i permessi predefiniti per i partecipanti a <strong> {conversationName}</strong>",
    "Start a call" : "Inizia la chiamata",
    "Skip the lobby" : "Salta la sala d'attesa",
    "Enable the microphone" : "Accendi il microfono",
    "Enable the camera" : "Abilita la fotocamera",
    "Share the screen" : "Condividi lo schermo",
    "Update permissions" : "Aggiorna i permessi",
    "Updating permissions" : "Aggiornamento dei permessi",
    "Create poll" : "Crea sondaggio",
    "Question" : "Domanda",
    "Answers" : "Risposte",
    "Settings" : "Impostazioni",
    "Anonymous poll" : "Sondaggio anonimo",
    "Open poll" : "Apri sondaggio",
    "Disable lobby" : "Disabilita l'ingresso",
    "Settings for participant \"{user}\"" : "Impostazioni per il partecipante \"{user}\"",
    "Participant \"{user}\"" : "Partecipante \"{user}\"",
    "moderator" : "moderatore",
    "bot" : "bot",
    "guest" : "ospite",
    "{time} talking …" : "{time} in conversazione...",
    "Raised their hand" : "Hanno alzato la mano",
    "Joined with video" : "Partecipa con video",
    "Joined via phone" : "Partecipa tramite telefono",
    "Joined with audio" : "Partecipa con audio",
    "Remove group and members" : "Rimuovi gruppo e membri",
    "Remove participant" : "Rimuovi partecipante",
    "Permissions granted to {displayName}" : "Permessi concessi a {displayName}",
    "Could not modify permissions for {displayName}" : "Impossibile modificare i permessi per {displayName}",
    "Permissions removed for {displayName}" : "Permessi rimossi per {displayName}",
    "Permissions set to default for {displayName}" : "Permessi impostati come predefiniti per {displayName}",
    "Dial-in PIN" : "PIN di accesso",
    "Demote from moderator" : "Declassa da moderatore",
    "Promote to moderator" : "Promuovi a moderatore",
    "Resend invitation" : "Nuovo invio dell'invito",
    "Reset custom permissions" : "Reimposta autorizzazioni personalizzate",
    "Grant all permissions" : "Concedi tutti i permessi",
    "Remove all permissions" : "Rimuovi tutte le autorizzazioni",
    "Remove" : "Rimuovi",
    "Permissions modified for {displayName}" : "Permessi modificati per {displayName}",
    "Add users or groups" : "Aggiungi utenti o gruppi",
    "Add users" : "Aggiungi utenti",
    "Add groups" : "Aggiungi gruppi",
    "Add other sources" : "Aggiungi altre fonti",
    "Add emails" : "Aggiungi email",
    "Integrations" : "Integrazioni",
    "Add federated users" : "Aggiungi utenti federati",
    "Searching …" : "Ricerca in corso...",
    "Search for more users" : "Cerca altri utenti",
    "Search or add participants" : "Cerca o aggiungi partecipanti",
    "An error occurred while adding the participants" : "Si è verificato un errore durante l'aggiunta dei partecipanti",
    "Participants" : "Partecipanti",
    "Participants ({count})" : "Partecipanti ({count})",
    "Open chat" : "Apri chat",
    "You have new unread messages in the chat." : "Hai nuovi messaggi non letti nella chat.",
    "You have been mentioned in the chat." : "Sei stato menzionato nella chat.",
    "Chat" : "Chat",
    "Details" : "Dettagli",
    "Shared items" : "Oggetti condivisi",
    "No results found" : "Nessun risultato trovato",
    "Load more results" : "Mostra altri risultati",
    "Projects" : "Progetti",
    "No shared items" : "Nessun elemento condiviso",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Collega a una conversazione",
    "Search conversations or users" : "Cerca conversazioni o utenti",
    "Select conversation" : "Seleziona conversazione",
    "Edit display name" : "Modifica nome visualizzato",
    "Choose the folder in which attachments should be saved." : "Scegli la cartella in cui salvare gli allegati.",
    "Select location for attachments" : "Seleziona la posizione per gli allegati",
    "Error while setting attachment folder" : "Errore durante l'impostazione della cartella degli allegati",
    "Your privacy setting has been saved" : "Le tue impostazioni di riservatezza sono state salvate",
    "Error while setting read status privacy" : "Errore durante l'impostazione della riservatezza dello stato di lettura",
    "Failed to save sounds setting" : "Errore nel salvare le impostazioni dei suoni ",
    "Sounds setting saved" : "Impostazione dei suoni salvata",
    "Error while saving sounds setting" : "Errore durante il salvataggio dell'impostazione dei suoni",
    "Attachments folder" : "Cartella degli allegati",
    "Browse …" : "Sfoglia ...",
    "Appearance" : "Aspetto",
    "Privacy" : "Riservatezza",
    "Share my read-status and show the read-status of others" : "Condividi il mio stato di lettura e mostra lo stato di lettura degli altri",
    "Share my typing-status and show the typing-status of others" : "Condividi il mio stato di digitazione e mostra lo stato di digitazione degli altri.",
    "Sounds" : "Suoni",
    "Play sounds when participants join or leave a call" : "Riproduci suoni quando i partecipanti entrano o abbandonano una chiamata",
    "Sounds can currently not be played on iPad and iPhone devices due to technical restrictions by the manufacturer." : "I suoni non possono essere riprodotti su iPad e iPhone al momento a causa di limitazioni tecniche imposte dai costruttori dei dispositivi.",
    "Sounds for chat and call notifications can be adjusted in the personal settings." : "I suoni della chat e le notifiche delle chiamate possono essere impostate nella sezione delle opzioni personali.",
    "Performance" : "Prestazioni",
    "Blur background image in the call (may increase GPU load)" : "Sfocatura dell'immagine di sfondo durante una chiamata (può aumentare il carico sulla GPU)",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Speed up your Talk experience with these quick shortcuts." : "Velocizza la tua esperienza di Talk con queste scorciatoie.",
    "Focus the chat input" : "Attiva la digitazione della chat",
    "Unfocus the chat input to use shortcuts" : "Disattiva la digitazione della chat per utilizzare le scorciatoie",
    "Fullscreen the chat or call" : "Chat a schermo intero o chiamata",
    "Search" : "Cerca",
    "Shortcuts while in a call" : "Scorciatoie durante una chiamata",
    "Camera on and off" : "Fotocamera attivo e disattivo",
    "Microphone on and off" : "Microfono attivo e disattivo",
    "Space bar" : "Barra spaziatrice",
    "Push to talk or push to mute" : "Premi per parlare o premi per silenziare",
    "Raise or lower hand" : "Alza o abbassa la mano",
    "More actions" : "Altre azioni",
    "Start call" : "Inizia chiamata",
    "You will be able to join the call only after a moderator starts it." : "Potrai unirti alla chiamata solo dopo che un moderatore l'abbia avviata.",
    "Recording" : "Registrazione",
    "Default" : "Predefinita",
    "You are not allowed to enable screensharing" : "Non sei autorizzato ad abilitare la condivisione dello schermo",
    "No screensharing" : "Nessuna condivisione dello schermo",
    "Screensharing options" : "Opzioni di condivisione dello schermo",
    "Enable screensharing" : "Abilita la condivisione dello schermo",
    "Bad sent video and screen quality." : "Qualità video e dello schermo inviate non corrette.",
    "Bad sent screen quality." : "Qualità dello schermo inviata non corretta.",
    "Bad sent video quality." : "Qualità del video inviata non corretta.",
    "Bad sent audio, video and screen quality." : "Qualità audio, video e dello schermo inviate non corrette.",
    "Bad sent audio and screen quality." : "Qualità audio e dello schermo inviate non corrette.",
    "Bad sent audio and video quality." : "Qualità dell'audio e del video inviate non corrette.",
    "Bad sent audio quality." : "Qualità audio inviata non corretta.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vedere il tuo schermo. Per migliorare la situazione prova, a disabilitare la sfocatura dello sfondo o il tuo video mentre fai una condivisione dello schermo.",
    "Disable background blur" : "Disattiva la sfocatura dello sfondo",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vedere il tuo schermo. Per migliorare la situazione, prova a disabilitare il tuo video durante una condivisione dello schermo.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vedere il tuo schermo.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di vederti.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "La tua connessione Internet o il tuo computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti e vederti. Per migliorare la situazione, prova a disabilitare la sfocatura dello sfondo o il tuo video durante la condivisione dello schermo.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti e vederti. Per migliorare la situazione prova a disabilitare il tuo video durante una condivisione dello schermo.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti e vedere il tuo schermo. Per migliorare la situazione prova a disabilitare la condivisione dello schermo.",
    "Disable screenshare" : "Disbilita la condivisione dello schermo",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "La tua connessione Internet o il tuo computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti e vederti. Per migliorare la situazione, prova a disabilitare la sfocatura dello sfondo o il tuo video.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti e vedere il tuo schermo. Per migliorare la situazione prova a disabilitare il tuo video.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "La tua connessione a Internet o il computer sono occupati e gli altri partecipanti potrebbero non essere in grado di capirti.",
    "Screen sharing is not supported by your browser." : "La condivisione dello schermo non è supportata dal tuo browser.",
    "Screen sharing requires the page to be loaded through HTTPS." : "La condivisione dello schermo richiede che la pagina sia caricata tramite HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "La condivisione dello schermo richiede che la pagina sia caricata tramite HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "La condivisione dello schermo funziona solo con la versione 52 o superiore di Firefox.",
    "Screensharing extension is required to share your screen." : "L'estensione di condivisione dello schermo è richiesta per condividere il tuo schermo.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Utilizza un browser diverso come Firefox o Chrome per condividere il tuo schermo.",
    "An error occurred while starting screensharing." : "Si è verificato un errore durante l'avvio della condivisione dello schermo.",
    "Show your screen" : "Mostra il tuo schermo",
    "Stop screensharing" : "Ferma la condivisione dello schermo",
    "Mute others" : "Silenzia gli altri",
    "Toggle full screen" : "Attiva schermo intero",
    "Select a region" : "Seleziona una regione",
    "Submit" : "Invia",
    "Search …" : "Cerca …",
    "Message without mention" : "Messaggio senza menzione",
    "Mention myself" : "Menziona me stesso",
    "The conversation does not exist" : "La conversazione non esiste",
    "Join a conversation or start a new one!" : "Unisciti a una conversazione o avviane una nuova!",
    "Duplicate session" : "Duplica sessione",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Ti sei unito alla conversazione in un'altra finestra o dispositivo. Questo non è attualmente supportato da Nextcloud Talk, quindi questa sessione è stata chiusa.",
    "Join a conversation or start a new one" : "Unisciti a una conversazione o avviane una nuova",
    "Nextcloud URL" : "URL Nextcloud",
    "Nextcloud user" : "Utente Nextcloud",
    "User password" : "Password utente",
    "Talk conversation" : "Conversazione di Talk",
    "Skip TLS verification" : "Salta la verifica TLS",
    "Matrix server URL" : "URL server Matrix",
    "User" : "Utente",
    "Matrix channel" : "Canale Matrix",
    "Mattermost server URL" : "URL server Mattermost",
    "Mattermost user" : "Utente Mattermost",
    "Team name" : "Nome squadra",
    "Channel name" : "Nome canale",
    "Rocket.Chat server URL" : "URL server Rocket.Chat",
    "User name or email address" : "Nome utente o indirizzo email",
    "Password" : "Password",
    "Rocket.Chat channel" : "Canale Rocket.Chat",
    "Zulip server URL" : "URL server Zulip",
    "Bot user name" : "Nome utente del bot",
    "Bot API key" : "Chiave API del bot",
    "Zulip channel" : "Canale Zulip",
    "API token" : "Token API",
    "Slack channel" : "Canale Slack",
    "Server ID or name" : "ID o nome del server",
    "Channel" : "Canale",
    "Login" : "Accedi",
    "Chat ID" : "ID chat",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL server IRC (ad es. chat.freenode.net:6667)",
    "Nickname" : "Pseudonimo",
    "Connection password" : "Password di connessione",
    "IRC channel" : "Canale IRC",
    "Channel password" : "Password del canale",
    "NickServ nickname" : "Pseudonimo NickServ",
    "NickServ password" : "Password NickServ",
    "Use TLS" : "Usa TLS",
    "Use SASL" : "Usa SASL",
    "Tenant ID" : "ID tenant",
    "Client ID" : "ID client",
    "Team ID" : "ID team",
    "Thread ID" : "ID thread",
    "XMPP/Jabber server URL" : "URL server XMPP/Jabber",
    "MUC server URL" : "URL server MUC",
    "Jabber ID" : "ID Jabber",
    "Media" : "Media",
    "Polls" : "Sondaggi",
    "Deck cards" : "Carte del mazzo",
    "Voice messages" : "Messaggi vocali",
    "Locations" : "Posizioni",
    "Audio" : "Audio",
    "Other" : "Altro",
    "Show all media" : "Mostra tutti i media",
    "Show all files" : "Mostra tutti i file",
    "Show all deck cards" : "Mostra tutte le carte del mazzo",
    "Show all voice messages" : "Mostra tutti i messaggi vocali",
    "Show all locations" : "Mostra tutte le località",
    "Show all audio" : "Mostra tutto l'audio",
    "Show all other" : "Mostra tutti gli altri",
    "Group" : "Gruppo",
    "Team" : "Team",
    "You: {lastMessage}" : "Tu: {lastMessage}",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Stai tentando di partecipare a una conversazione mentre hai una sessione attiva in un'altra finestra o dispositivo. Questo non è attualmente supportato da Nextcloud Talk. Che cosa vuoi fare?",
    "Leave this page" : "Abbandona questa pagina",
    "Join here" : "Unisciti qui",
    "Post to a conversation" : "Pubblica in una conversazione",
    "Post to conversation" : "Pubblica in conversazione",
    "Error while clearing conversation history" : "Errore durante la cancellazione della cronologia della conversazione",
    "Error occurred while allowing guests" : "Si è verificato un errore durante l'autorizzazione degli ospiti",
    "Error occurred while disallowing guests" : "Si è verificato un errore durante la disabilitazione degli ospiti",
    "Error occurred when restricting the conversation to moderator" : "Si è verificato un errore durante la limitazione della conversazione al moderatore",
    "Error occurred when opening the conversation to everyone" : "Si è verificato un errore durante l'apertura della conversazione a tutti",
    "Conversation password has been saved" : "La password della conversazione è stata salvata",
    "Conversation password has been removed" : "La password della conversazione è stata rimossa",
    "Error occurred while saving conversation password" : "Si è verificato un errore durante il salvataggio della password della conversazione",
    "Error while uploading file \"{fileName}\"" : "Errore durante il caricamento del file \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Spazio libero insufficiente per caricare il file \"{fileName}\"",
    "Error while sharing file" : "Errore durante la condivisione del file",
    "Could not post message: {errorMessage}" : "Impossibile pubblicare il messaggio: {errorMessage}",
    "An error occurred while fetching the participants" : "Si è verificato un errore durante il recupero dei partecipanti",
    "Could not send invitation to {actorId}" : "Impossibile inviare l'invito a {actorId}",
    "Invitations sent" : "Inviti inviati",
    "Error occurred when sending invitations" : "Si è verificato un errore durante l'invio degli inviti",
    "Failed to add reaction" : "Impossibile aggiungere la reazione",
    "Failed to remove reaction" : "Impossibile rimuovere la reazione",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Il browser che stai utilizzando non è completamente supportato da Nextcloud Talk. Usa l'ultima versione di Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
    "Error while parsing a PROPFIND error" : "Errore durante l'elaborazione di un errore PROPFIND",
    "Lost connection to signaling server. Trying to reconnect." : "Connessione al server di segnalazione interrotta. Riprova a connetterti.",
    "Establishing signaling connection is taking longer than expected …" : "La creazione della connessione di segnalazione sta richiedendo più tempo del previsto…",
    "Failed to establish signaling connection. Retrying …" : "Creazione della connessione di segnalazione non riuscita. Nuovo tentativo…",
    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Creazione della connessione di segnalazione non riuscita. Potrebbe esserci qualcosa di sbagliato nella configurazione del server di segnalazione",
    "Please reload the page." : "Ricarica la pagina.",
    "Do not disturb" : "Non disturbare",
    "Away" : "Assente",
    "Microphone {number}" : "Microfono {number}",
    "Camera {number}" : "Fotocamera {number}",
    "Speaker {number}" : "Altoparlante {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Sembra che tu abbia parlato mentre eri silenziato, rimuovi il silenzio perché gli altri possano sentirti",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Impossibile stabilire una connessione con almeno un partecipante. Un server TURN potrebbe essere necessario in questo scenario. Chiedi al tuo amministratore di configurarne uno seguendo {linkstart}questa documentazione{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "L'operazione sta richiedendo più tempo del previsto. I permessi multimediali sono già stati accordati (o rifiutati)? Se sì, riavvia il browser, poiché audio e video non funzionano",
    "Access to microphone & camera is only possible with HTTPS" : "L'accesso a microfono e fotocamera è possibile solo con HTTPS",
    "Please move your setup to HTTPS" : "Sposta la tua configurazione su HTTPS",
    "Access to microphone & camera was denied" : "L'accesso a microfono e fotocamera è stato negato",
    "WebRTC is not supported in your browser" : "WebRTC non è supportato dal tuo browser",
    "Please use a different browser like Firefox or Chrome" : "Utilizza un browser diverso come Firefox o Chrome",
    "Error while accessing microphone & camera" : "Errore durante l'accesso a microfono e fotocamera",
    "The password is wrong. Try again." : "La password è errata. Prova ancora.",
    "%s Talk on your mobile devices" : "%s Talk sui tuoi dispositivi mobili ",
    "Join conversations at any time, anywhere, on any device." : "Unisciti alle conversazioni in qualsiasi momento, ovunque, su qualsiasi dispositivo.",
    "Android app" : "Applicazione Android",
    "iOS app" : "Applicazione iOS",
    "__language_name__" : "Italiano",
    "Tasks" : "Attività",
    "Notes" : "Note",
    "Reports" : "Reports",
    "You tried to call {user}" : "Hai provato a chiamare {user}",
    "%s invited you to a conversation." : "%s ti ha invitato a una conversazione.",
    "You were invited to a conversation." : "Sei stato invitato a una conversazione.",
    "Click the button below to join." : "Fai clic sul pulsante sotto per partecipare.",
    "Join »%s«" : "Unisciti a «%s»",
    "{user} invited you to a private conversation" : "{user} ti ha invitato a una conversazione privata",
    "Always show the device preview screen before joining a call in this conversation." : "Mostra sempre la schermata di anteprima del dispositivo prima di partecipare a una chiamata in questa conversazione.",
    "Copy conversation link" : "Copia collegamento della conversazione",
    "Call without notification" : "Chiama senza notifica",
    "Close" : "Chiudi",
    "Choose devices" : "Scegli i dispositivi",
    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk è stato aggiornato, devi ricaricare la pagina prima di poter iniziare o partecipare a una chiamata.",
    "Blur background" : "Sfocatura dello sfondo",
    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk è stato aggiornato, ricarica la pagina",
    "An error happened when trying to share your file" : "Si è verificato un errore durante il tentativo di condividere il tuo file",
    "Failed to join the conversation. Try to reload the page." : "Partecipazione alla conversazione non riuscita. Prova a ricaricare la pagina.",
    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud è in manutenzione, ricarica la pagina",
    "Lost connection to signaling server. Try to reload the page manually." : "Connessione al server di segnalazione interrotta. Prova a ricaricare manualmente la pagina."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
